@@ -54,12 +54,14 @@ class KdeFrontend(Frontend, QObject):
         from dbus.mainloop.qt import DBusQtMainLoop
         DBusQtMainLoop(set_as_default=True)
 
-    def __init__(self, backend, img=None, persistent=True):
+    def __init__(self, backend, img=None, persistent=True,
+                 allow_system_internal=False):
         QObject.__init__(self)
 
         #our passed vars - keep them private
         self.__persistent = persistent
         self.__img = img
+        self.__allow_system_internal = allow_system_internal
 
         # Perform some initialization
         self.__initPrivateVars()
@@ -119,7 +121,7 @@ class KdeFrontend(Frontend, QObject):
         else:
             file =  KStandardDirs.locate("appdata", self.__mainWindow_ui)
             appdir = file.left(file.lastIndexOf("/"))
-        uic.loadUi(appdir + "/" + self.__mainWindow_ui, self.__mainWindow)
+        uic.loadUi(unicode(appdir + "/" + self.__mainWindow_ui), self.__mainWindow)
 
         #set default persist size
         self.__mainWindow.ui_persist_label.setText(format_mb_size(128))
@@ -354,16 +356,20 @@ class KdeFrontend(Frontend, QObject):
         if not source:
             return
         stype = self.__backend.sources[source]['type']
-        if status == CAN_USE or stype == SOURCE_IMG:
+        if (status == CAN_USE or 
+         (self.__mainWindow.ui_start_button.isEnabled() and stype == SOURCE_IMG)):
             self.__mainWindow.ui_start_button.setEnabled(True)
         else:
             self.__mainWindow.ui_start_button.setEnabled(False)
+            status = NEED_FORMAT
         # Update the destination status message.
         if status == CANNOT_USE:
             msg = _('The device is not large enough to hold this image.')
         elif status == NEED_SPACE:
             msg = _('There is not enough free space for this image.')
             # FIXME RBG: 04/01/10 - Need Open button for folder to device for removing files
+        elif status == NEED_FORMAT:
+            msg = _('The device needs to be formatted for use.')
         else:
             msg = ''
         self.__mainWindow.ui_dest_status.setText(msg)
@@ -416,7 +422,8 @@ class KdeFrontend(Frontend, QObject):
             self.progress_bar.setLabelText(starting_up)
             self.progress_bar.show()
             try:
-                self.__backend.install(source, target, persist)
+                self.__backend.install(source, target, persist,
+                                       allow_system_internal=self.__allow_system_internal)
             except:
                 self.__fail()
         else:
